@@ -6,6 +6,7 @@ from platform import system
 from typing import Any
 from typing import Dict
 from typing import List
+from typing import Optional
 from typing import Union
 
 from ddtrace.appsec._ddwaf.waf_stubs import ddwaf_builder_capsule
@@ -174,6 +175,15 @@ class ddwaf_object(ctypes.Structure):
     def create_without_limits(cls, struct: DDWafRulesType) -> "ddwaf_object":
         return cls(struct, max_objects=DDWAF_NO_LIMIT, max_depth=DDWAF_DEPTH_NO_LIMIT, max_string_length=DDWAF_NO_LIMIT)
 
+    @classmethod
+    def from_json_bytes(cls, data: bytes) -> Optional["ddwaf_object"]:
+        """Create a ddwaf_object from a JSON string as bytes."""
+        obj = cls.__new__(cls)
+        if not ddwaf_object_from_json(obj, data, len(data)):
+            log.debug("Failed to create ddwaf_object from JSON: %s", data)
+            return None
+        return obj
+
     @property
     def struct(self) -> DDWafRulesType:
         """Generate a python structure from ddwaf_object"""
@@ -406,6 +416,23 @@ def py_ddwaf_builder_build_instance(builder: ddwaf_builder_capsule) -> ddwaf_han
     return ddwaf_handle_capsule(ddwaf_builder_build_instance(builder.builder), ddwaf_destroy)
 
 
+ddwaf_builder_get_config_paths = ctypes.CFUNCTYPE(
+    ctypes.c_uint32, ddwaf_builder, ddwaf_object_p, ctypes.c_char_p, ctypes.c_uint32
+)(
+    ("ddwaf_builder_get_config_paths", ddwaf),
+    (
+        (1, "builder"),
+        (1, "paths"),
+        (1, "filter"),
+        (1, "filter_len"),
+    ),
+)
+
+
+def py_ddwaf_builder_get_config_paths(builder: ddwaf_builder_capsule, filter_str: str) -> int:
+    return ddwaf_builder_get_config_paths(builder.builder, None, filter_str.encode(), len(filter_str))
+
+
 ddwaf_builder_destroy = ctypes.CFUNCTYPE(None, ddwaf_builder)(
     ("ddwaf_builder_destroy", ddwaf),
     ((1, "builder"),),
@@ -525,6 +552,15 @@ ddwaf_object_map_add = ctypes.CFUNCTYPE(ctypes.c_bool, ddwaf_object_p, ctypes.c_
 # ddwaf_object_get_bool https://github.com/DataDog/libddwaf/commit/7dc68dacd972ae2e2a3c03a69116909c98dbd9cb
 # ddwaf_object_get_float
 
+ddwaf_object_from_json = ctypes.CFUNCTYPE(ctypes.c_bool, ddwaf_object_p, ctypes.c_char_p, ctypes.c_uint32)(
+    ("ddwaf_object_from_json", ddwaf),
+    (
+        (3, "output"),
+        (1, "json_str"),
+        (1, "length"),
+    ),
+)
+
 
 ddwaf_get_version = ctypes.CFUNCTYPE(ctypes.c_char_p)(
     ("ddwaf_get_version", ddwaf),
