@@ -5,7 +5,6 @@ from wrapt import wrap_function_wrapper as _w
 
 import ddtrace
 from ddtrace import config
-from ddtrace._logger import LogInjectionState
 from ddtrace.contrib.internal.trace_utils import unwrap as _u
 from ddtrace.internal.utils import get_argument_value
 
@@ -27,7 +26,7 @@ def _supported_versions() -> Dict[str, str]:
 
 def _w_process_record(func, instance, args, kwargs):
     # patch logger to include datadog info before logging
-    if config._logs_injection != LogInjectionState.DISABLED:
+    if config._logs_injection:
         record = get_argument_value(args, kwargs, 0, "record")
         record.extra.update(ddtrace.tracer.get_log_correlation_context())
     return func(*args, **kwargs)
