@@ -70,6 +70,7 @@ IP_PATTERNS = (
     "x-real-ip",
     "true-client-ip",
     "x-client-ip",
+    "forwarded",
     "forwarded-for",
     "x-cluster-client-ip",
     "fastly-client-ip",
@@ -132,6 +133,23 @@ def _get_request_header_referrer_host(headers, headers_are_case_sensitive=False)
     return ""
 
 
+def _parse_ip_header(ip_header_value: str) -> str:
+    """Parse the ip header, either in Forwarded-For format or Forwarded format.
+
+    references: https://developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/Forwarded
+    """
+    IP_EXTRACTIONS = [
+        r"^\s*(?P<ip>[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)$",  # ipv4 simple format
+        r'(?:^|;)\s*for="?(?P<ip>[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+)',  # ipv4 forwarded format
+        r"^\s*(?P<ip>[0-9a-fA-F:]+)$",  # ipv6 simple format
+        r'(?:^|;)\s*for="\[(?P<ip>[0-9a-fA-F:]+)\]',  # ipv6 forwarded format
+    ]
+    for pattern in IP_EXTRACTIONS:
+        if m := re.search(pattern, ip_header_value, re.IGNORECASE):
+            return m.group("ip")
+    return ""
+
+
 def _get_request_header_client_ip(headers, peer_ip=None, headers_are_case_sensitive=False):
     # type: (Optional[Mapping[str, str]], Optional[str], bool) -> str
 
@@ -184,12 +202,12 @@ def _get_request_header_client_ip(headers, peer_ip=None, headers_are_case_sensit
 
     if ip_header_value:
         # At this point, we have one IP header, check its value and retrieve the first public IP
+
         ip_list = ip_header_value.split(",")
         for ip in ip_list:
-            ip = ip.strip()
+            ip = _parse_ip_header(ip)
             if not ip:
                 continue
-
             try:
                 if ip_is_global(ip):
                     return ip
