@@ -13,9 +13,11 @@ from ddtrace.internal.utils.formats import asbool
 def _get_default_test_visibility_contrib_config() -> t.Dict[str, t.Any]:
     return dict(
         _default_service="default_test_visibility_service",
-        itr_skipping_level=ITR_SKIPPING_LEVEL.SUITE
-        if asbool(os.getenv("_DD_CIVISIBILITY_ITR_SUITE_MODE"))
-        else ITR_SKIPPING_LEVEL.TEST,
+        itr_skipping_level=(
+            ITR_SKIPPING_LEVEL.SUITE
+            if asbool(os.getenv("_DD_CIVISIBILITY_ITR_SUITE_MODE", True))
+            else ITR_SKIPPING_LEVEL.TEST
+        ),
         _itr_skipping_ignore_parameters=False,
     )
 
