@@ -249,6 +249,7 @@ class RemoteConfigClient:
         # called after the process is forked to declare a new id
         self.id = str(uuid.uuid4())
         self._client_tracer["runtime_id"] = runtime.get_runtime_id()
+        self._applied_configs.clear()
 
     def register_product(self, product_name: str, pubsub_instance: Optional[PubSub] = None) -> None:
         if pubsub_instance is not None:
@@ -294,12 +295,8 @@ class RemoteConfigClient:
     def _send_request(self, payload: str) -> Optional[Mapping[str, Any]]:
         conn = None
         try:
-            log.debug(
-                "[%s][P: %s] Requesting RC data from products: %s", os.getpid(), os.getppid(), str(self._products)
-            )  # noqa: G200
-
             if config.log_payloads:
-                log.debug("[%s][P: %s] RC request payload: %s", os.getpid(), os.getppid(), payload)  # noqa: G200
+                log.debug("[%s][P: %s] RC request payload: %s", os.getpid(), os.getppid(), payload)
 
             conn = agent.get_connection(self.agent_url, timeout=agent_config.trace_agent_timeout_seconds)
             conn.request("POST", REMOTE_CONFIG_AGENT_ENDPOINT, payload, self._headers)
@@ -311,11 +308,9 @@ class RemoteConfigClient:
             data = resp.read()
 
             if config.log_payloads:
-                log.debug(
-                    "[%s][P: %s] RC response payload: %s", os.getpid(), os.getppid(), data.decode("utf-8")
-                )  # noqa: G200
+                log.debug("[%s][P: %s] RC response payload: %s", os.getpid(), os.getppid(), data.decode("utf-8"))
         except OSError as e:
-            log.debug("Unexpected connection error in remote config client request: %s", str(e))  # noqa: G200
+            log.debug("Unexpected connection error in remote config client request: %s", str(e))
             return None
         finally:
             if conn is not None:
