@@ -1,4 +1,4 @@
-import time
+import time as builtin_time
 from types import TracebackType
 from typing import Optional
 from typing import Type  # noqa:F401
@@ -9,6 +9,22 @@ from ddtrace.internal.logger import get_logger
 log = get_logger(__name__)
 
 
+class Time:
+    """
+    References to the standard Python time functions that won't be clobbered by `freezegun`.
+
+    `freezegun`_ scans all loaded modules to check for imported functions from the `time` module, but it does not look
+    inside classes or other objects, so these references are safe to use in the tracer.
+
+    .. _freezegun: https://github.com/spulec/freezegun/blob/1.5.3/freezegun/api.py#L817
+    """
+
+    time = builtin_time.time
+    time_ns = builtin_time.time_ns
+    monotonic = builtin_time.monotonic
+    monotonic_ns = builtin_time.monotonic_ns
+
+
 class StopWatch(object):
     """A simple timer/stopwatch helper class.
 
@@ -31,7 +47,7 @@ class StopWatch(object):
     def start(self):
         # type: () -> StopWatch
         """Starts the watch."""
-        self._started_at = time.monotonic()
+        self._started_at = Time.monotonic()
         return self
 
     def elapsed(self) -> float:
@@ -44,7 +60,7 @@ class StopWatch(object):
         if self._started_at is None:
             raise RuntimeError("Can not get the elapsed time of a stopwatch if it has not been started/stopped")
         if self._stopped_at is None:
-            now = time.monotonic()
+            now = Time.monotonic()
         else:
             now = self._stopped_at
         return now - self._started_at
@@ -66,7 +82,7 @@ class StopWatch(object):
         """Stops the watch."""
         if self._started_at is None:
             raise RuntimeError("Can not stop a stopwatch that has not been started")
-        self._stopped_at = time.monotonic()
+        self._stopped_at = Time.monotonic()
         return self
 
 
@@ -74,7 +90,7 @@ class HourGlass(object):
     """An implementation of an hourglass."""
 
     def __init__(self, duration: float) -> None:
-        t = time.monotonic()
+        t = Time.monotonic()
 
         self._duration = duration
         self._started_at = t - duration
@@ -84,7 +100,7 @@ class HourGlass(object):
 
     def turn(self) -> None:
         """Turn the hourglass."""
-        t = time.monotonic()
+        t = Time.monotonic()
         top_0 = self._end_at - self._started_at
         bottom = self._duration - top_0 + min(t - self._started_at, top_0)
 
@@ -104,7 +120,7 @@ class HourGlass(object):
 
     def _trickling(self):
         # type: () -> bool
-        if time.monotonic() < self._end_at:
+        if Time.monotonic() < self._end_at:
             return True
 
         # No longer trickling, so we change state
