@@ -1,7 +1,6 @@
 from .anthropic import AnthropicIntegration
 from .base import BaseLLMIntegration
 from .bedrock import BedrockIntegration
-from .crewai import CrewAIIntegration
 from .gemini import GeminiIntegration
 from .google_genai import GoogleGenAIIntegration
 from .langchain import LangChainIntegration
@@ -15,7 +14,6 @@ __all__ = [
     "AnthropicIntegration",
     "BaseLLMIntegration",
     "BedrockIntegration",
-    "CrewAIIntegration",
     "GeminiIntegration",
     "GoogleGenAIIntegration",
     "LangChainIntegration",
