@@ -15,6 +15,7 @@ from ddtrace.internal.utils.formats import format_trace_id
 from ddtrace.llmobs._constants import LLMOBS_TRACE_ID
 from ddtrace.llmobs._integrations.bedrock_utils import parse_model_id
 from ddtrace.llmobs._utils import _get_ml_app
+from ddtrace.llmobs._utils import _get_session_id
 from ddtrace.llmobs._utils import safe_json
 
 
@@ -57,12 +58,15 @@ def _build_span_event(
     llmobs_trace_id = root_span._get_ctx_item(LLMOBS_TRACE_ID)
     if llmobs_trace_id is None:
         llmobs_trace_id = root_span.trace_id
+    session_id = _get_session_id(root_span)
+    ml_app = _get_ml_app(root_span)
+    tags = [f"ml_app:{ml_app}", f"session_id:{session_id}", "integration:bedrock_agents"]
     span_event = {
         "name": span_name,
         "span_id": str(span_id),
         "trace_id": format_trace_id(llmobs_trace_id),
         "parent_id": str(parent_id or root_span.span_id),
-        "tags": ["ml_app:{}".format(_get_ml_app(root_span))],
+        "tags": tags,
         "start_ns": int(start_ns or root_span.start_ns),
         "duration": int(duration_ns or DEFAULT_SPAN_DURATION),
         "status": "error" if error else "ok",
