@@ -9,10 +9,12 @@ from typing import Union
 from typing import cast
 from weakref import WeakKeyDictionary
 
+from ddtrace._trace.pin import Pin
 from ddtrace.internal.logger import get_logger
 from ddtrace.internal.utils import get_argument_value
 from ddtrace.internal.utils.formats import format_trace_id
 from ddtrace.llmobs import LLMObs
+from ddtrace.llmobs._constants import AGENT_MANIFEST
 from ddtrace.llmobs._constants import INPUT_VALUE
 from ddtrace.llmobs._constants import NAME
 from ddtrace.llmobs._constants import OUTPUT_VALUE
@@ -34,10 +36,41 @@ logger = get_logger(__name__)
 PREGEL_PUSH = "__pregel_push"  # represents a task queued up by a `Send` command
 PREGEL_TASKS = "__pregel_tasks"  # name of ephemeral channel that pregel `Send` commands write to
 
+ALLOWED_MODEL_SETTINGS_KEYS = [
+    "max_tokens",
+    "temperature",
+    "top_p",
+    "top_k",
+    "frequency_penalty",
+    "presence_penalty",
+    "stop",
+    "n",
+    "logprobs",
+    "echo",
+    "logit_bias",
+]
+
 
 class LangGraphIntegration(BaseLLMIntegration):
     _integration_name = "langgraph"
     _graph_nodes_for_graph_by_task_id: WeakKeyDictionary[Span, Dict[str, Any]] = WeakKeyDictionary()
+    _agent_manifests: WeakKeyDictionary[Any, Dict[str, Any]] = WeakKeyDictionary()
+    _graph_spans_to_graph_instances: WeakKeyDictionary[Span, Any] = WeakKeyDictionary()
+
+    def trace(
+        self,
+        pin: Pin,
+        operation_id: str,
+        submit_to_llmobs: bool = False,
+        instance=None,
+        **kwargs,
+    ) -> Span:
+        span = super().trace(pin, operation_id, submit_to_llmobs, **kwargs)
+
+        if instance:
+            self._graph_spans_to_graph_instances[span] = instance
+
+        return span
 
     def _llmobs_set_tags(
         self,
@@ -82,6 +115,37 @@ class LangGraphIntegration(BaseLLMIntegration):
             }
         )
 
+        if operation == "graph":
+            agent = self._graph_spans_to_graph_instances[span]
+            agent_manifest = self._get_agent_manifest(agent, args, config)
+            span._set_ctx_item(AGENT_MANIFEST, agent_manifest)
+
+    def _get_agent_manifest(self, agent, args, config: Dict[str, Any]) -> Optional[Dict[str, Any]]:
+        """Gets the agent manifest for a given agent at the end of its execution."""
+        if agent is None:
+            return None
+
+        agent_manifest = self._agent_manifests.get(agent)
+        if agent_manifest is None:
+            tools = _get_tools_from_graph(agent)
+            agent_manifest = {"name": agent.name or "LangGraph", "tools": tools}
+            self._agent_manifests[agent] = agent_manifest
+
+        if "framework" not in agent_manifest:
+            agent_manifest["framework"] = "LangGraph"
+        if "max_iterations" not in agent_manifest:
+            agent_manifest["max_iterations"] = _get_attr(config, "recursion_limit", 25)
+
+        if (
+            "dependencies" not in agent_manifest
+            and isinstance(args, tuple)
+            and len(args) > 0
+            and isinstance(args[0], dict)
+        ):
+            agent_manifest["dependencies"] = list(args[0].keys())
+
+        return agent_manifest
+
     def _get_node_metadata_from_span(self, span: Span, instance_id: str) -> Dict[str, Any]:
         """
         Get the node metadata for a given span and its node instance id.
@@ -97,6 +161,44 @@ class LangGraphIntegration(BaseLLMIntegration):
         invoked_node["span"] = {"trace_id": format_trace_id(span.trace_id), "span_id": str(span.span_id)}
         return invoked_node
 
+    def llmobs_handle_agent_manifest(self, agent, args: tuple, kwargs: dict):
+        """
+        Handles the agent manifest for a given react agent (defined through `langgraph.prebuilt.create_react_agent`),
+        and caches it for use when tagging the graph/agent span in the `_get_agent_manifest`.
+        """
+        if not self.llmobs_enabled:
+            return
+
+        model = get_argument_value(
+            args, kwargs, 0, "model", True
+        )  # required parameter on the langgraph side, but optional should that ever change
+        model_name, model_provider, model_settings = _get_model_info(model)
+
+        agent_tools: List[Any] = (
+            get_argument_value(args, kwargs, 1, "tools", True) or []
+        )  # required parameter on the langgraph side, but optional should that ever change
+        tools = _get_tools_from_react_agent(agent_tools)
+
+        system_prompt: Optional[str] = _get_system_prompt_from_react_agent(kwargs.get("prompt"))
+        name: Optional[str] = kwargs.get("name")
+
+        agent_manifest: Dict[str, Any] = {}
+
+        if model_name:
+            agent_manifest["model"] = model_name
+        if model_provider:
+            agent_manifest["model_provider"] = model_provider
+        if model_settings:
+            agent_manifest["model_settings"] = model_settings
+        if tools:
+            agent_manifest["tools"] = tools
+        if system_prompt:
+            agent_manifest["instructions"] = system_prompt
+        if name:
+            agent_manifest["name"] = name
+
+        self._agent_manifests[agent] = agent_manifest
+
     def llmobs_handle_pregel_loop_tick(
         self, finished_tasks: dict, next_tasks: dict, more_tasks: bool, is_subgraph_node: bool = False
     ):
@@ -161,7 +263,7 @@ class LangGraphIntegration(BaseLLMIntegration):
         used_finished_task_ids: Set[str] = set()
         for task_id, task in next_tasks.items():
             queued_node = self._graph_nodes_for_graph_by_task_id.setdefault(graph_span, {}).setdefault(task_id, {})
-            queued_node["name"] = getattr(task, "name", "")
+            queued_node["name"] = _get_attr(task, "name", "")
 
             trigger_ids = self._link_task_to_triggers(
                 task, queued_node, graph_span, task_trigger_channels_to_finished_tasks
@@ -229,6 +331,133 @@ class LangGraphIntegration(BaseLLMIntegration):
         graph_span._set_ctx_item(SPAN_LINKS, graph_span_links)
 
 
+def _get_model_info(model) -> Tuple[Optional[str], Optional[str], Dict[str, Any]]:
+    """Get the model name, provider, and settings from a langchain llm"""
+    if isinstance(model, str):
+        # something like "openai:gpt-4"
+        model_provider_str, model_name_str = model.split(":", maxsplit=1)
+        return model_name_str, model_provider_str, {}
+
+    model_name = _get_attr(model, "model_name", None)
+    model_provider = _get_model_provider(model)
+    model_settings = _get_model_settings(model)
+    return model_name, model_provider, model_settings
+
+
+def _get_model_provider(model) -> Optional[str]:
+    """Get the model provider from a langchain llm"""
+    model_provider_info_fn = _get_attr(model, "_get_ls_params", None)
+    if model_provider_info_fn is None or not callable(model_provider_info_fn):
+        return None
+
+    model_provider_info: Dict[str, Any] = model_provider_info_fn()
+    return model_provider_info.get("ls_provider", None)
+
+
+def _get_model_settings(model) -> Dict[str, Any]:
+    """Get the model settings from a langchain llm"""
+    model_dict_fn = _get_attr(model, "dict", None)
+    if model_dict_fn is None or not callable(model_dict_fn):
+        return {}
+
+    model_dict: dict = model.dict()
+    return {key: value for key, value in model_dict.items() if key in ALLOWED_MODEL_SETTINGS_KEYS and value}
+
+
+def _get_system_prompt_from_react_agent(system_prompt) -> Optional[str]:
+    """
+    Get the system prompt from a react agent.
+
+    The system prompt can be:
+    - a string
+    - a dict with a "content" key
+    - a Callable that returns a string or dict
+
+    In the case of a Callable (which is dynamic as a function of state and config), we end up returning None.
+    """
+    if system_prompt is None:
+        return None
+
+    if isinstance(system_prompt, str):
+        return system_prompt
+
+    return _get_attr(system_prompt, "content", None)
+
+
+def _get_tools_from_react_agent(tools):
+    """
+    Get the tools for the agent manifest passed into the react agent.
+
+    Tools can be:
+    - a ToolNode
+    - a list of BaseTools (langchain tools)
+    - a list of Callables
+    - a list of dicts
+
+    In the case of a Callable (which is dynamic as a function of state and config), we end up returning None.
+    """
+    if _is_tool_node(tools):
+        tools_by_name: Dict[str, Any] = _get_attr(tools, "tools_by_name", {})
+        tools = list(tools_by_name.values())
+
+    return _extract_tools(tools)
+
+
+def _get_tool_repr_from_langchain_base_tool(tool) -> Optional[Dict[str, Any]]:
+    """Get the tool representation from a langchain base tool"""
+    if tool is None or isinstance(tool, dict):
+        return None
+
+    return {
+        "name": _get_attr(tool, "name", ""),
+        "description": _get_attr(tool, "description", ""),
+        "parameters": _get_attr(tool, "args", {}),
+    }
+
+
+def _is_tool_node(maybe_tool_node):
+    """Check if a node is a tool node without a specific instance check"""
+    return _get_attr(maybe_tool_node, "tools_by_name", None) is not None
+
+
+def _get_tools_from_graph(agent) -> list:
+    """Get the tools from the ToolNode(s) of an agent/graph"""
+    graph_tools: List[Dict[str, Any]] = []
+    if agent is None:
+        return graph_tools
+
+    builder = _get_attr(agent, "builder", None)
+    if builder is None:
+        return graph_tools
+
+    nodes = _get_attr(builder, "nodes", None)
+    if nodes is None or not isinstance(nodes, dict):
+        return graph_tools
+
+    for node in nodes.values():
+        runnable = _get_attr(node, "runnable", None)
+        if runnable is None:
+            continue
+
+        if not _is_tool_node(runnable):
+            continue
+
+        tools_by_name: Dict[str, Any] = _get_attr(runnable, "tools_by_name", {})
+        graph_tools.extend(_extract_tools(tools_by_name.values()))
+
+    return graph_tools
+
+
+def _extract_tools(tools: Iterable[Any]) -> List[Dict[str, Any]]:
+    """Extract the tool representations from a list of tools"""
+    tools_repr = []
+    for tool in tools:
+        tool_repr = _get_tool_repr_from_langchain_base_tool(tool)
+        if tool_repr:
+            tools_repr.append(tool_repr)
+    return tools_repr
+
+
 def _get_trigger_ids_from_finished_tasks(
     queued_tasks,
     task_trigger_channels_to_finished_tasks: Dict[str, List[Union[str, Tuple[str, str]]]],
@@ -241,7 +470,7 @@ def _get_trigger_ids_from_finished_tasks(
     consume from the `__pregel_tasks` channel. We want to pop these instances and associate them one at a time with each
     of the queued tasks.
     """
-    task_triggers_from_task = getattr(queued_tasks, "triggers", [])
+    task_triggers_from_task = _get_attr(queued_tasks, "triggers", [])
     task_triggers = task_triggers_from_task or []
 
     trigger_ids: List[str] = []
@@ -264,7 +493,7 @@ def _find_pregel_push_index(task, pregel_pushes: List[Tuple[str, str]]) -> int:
     Find the index of a specific pregel push node in the list of pregel push nodes
     """
     for i, (pregel_push_node, _) in enumerate(pregel_pushes):
-        if pregel_push_node == getattr(task, "name", ""):
+        if pregel_push_node == _get_attr(task, "name", ""):
             return i
     return -1
 
@@ -279,7 +508,7 @@ def _map_channel_writes_to_finished_tasks_ids(
     """
     channel_names_to_finished_tasks_ids: Dict[str, List[Union[str, Tuple[str, str]]]] = {}
     for finished_task_id, finished_task in finished_tasks.items():
-        writes: Iterable[Tuple[str, Any]] = getattr(finished_task, "writes", [])
+        writes: Iterable[Tuple[str, Any]] = _get_attr(finished_task, "writes", [])
         for write in writes:
             _append_finished_task_to_channel_writes_map(finished_task_id, write, channel_names_to_finished_tasks_ids)
 
@@ -300,7 +529,7 @@ def _append_finished_task_to_channel_writes_map(
     tasks_for_trigger = channel_names_to_finished_tasks_ids.setdefault(channel_write_name, [])
 
     if channel_write_name == PREGEL_TASKS:
-        pregel_task_node: Optional[str] = getattr(channel_write_arg, "node", None)
+        pregel_task_node: Optional[str] = _get_attr(channel_write_arg, "node", None)
         if pregel_task_node is None:
             return
         tasks_for_trigger.append((pregel_task_node, finished_task_id))
