@@ -8,6 +8,7 @@ from typing import Literal  # noqa:F401
 from typing import Optional  # noqa:F401
 from typing import Text  # noqa:F401
 from typing import Tuple  # noqa:F401
+from typing import Union
 from typing import cast  # noqa:F401
 import urllib.parse
 
@@ -19,8 +20,12 @@ from ddtrace._trace.span import _get_64_lowest_order_bits_as_int
 from ddtrace._trace.span import _MetaDictType
 from ddtrace.appsec._constants import APPSEC
 from ddtrace.internal import core
+from ddtrace.internal.telemetry import telemetry_writer
+from ddtrace.internal.telemetry.constants import TELEMETRY_NAMESPACE
+from ddtrace.internal.utils.deprecations import DDTraceDeprecationWarning
 from ddtrace.settings._config import config
 from ddtrace.settings.asm import config as asm_config
+from ddtrace.vendor.debtcollector import deprecate
 
 from ..constants import AUTO_KEEP
 from ..constants import AUTO_REJECT
@@ -151,6 +156,20 @@ def _dd_id_to_b3_id(dd_id):
     return "{:016x}".format(dd_id)
 
 
+def _record_http_telemetry(metric_name: str, header_style: str) -> None:
+    """Record telemetry metric for HTTP propagation operations.
+
+    :param metric_name: The name of the metric to record
+    :param tags: Tuple of tag key-value pairs to include with the metric
+    """
+    telemetry_writer.add_count_metric(
+        namespace=TELEMETRY_NAMESPACE.TRACERS,
+        name=metric_name,
+        value=1,
+        tags=(("header_style", header_style),),
+    )
+
+
 class _DatadogMultiHeader:
     """Helper class for injecting/extract Datadog multi header format
 
@@ -288,6 +307,9 @@ class _DatadogMultiHeader:
                 span_context._meta["_dd.propagation_error"] = "encoding_error"
                 log.warning("failed to encode x-datadog-tags", exc_info=True)
 
+        # Record telemetry for successful injection
+        _record_http_telemetry("context_header_style.injected", PROPAGATION_STYLE_DATADOG)
+
     @staticmethod
     def _extract(headers):
         # type: (Dict[str, str]) -> Optional[Context]
@@ -445,6 +467,9 @@ class _B3MultiHeader:
             elif sampling_priority > 1:
                 headers[_HTTP_HEADER_B3_FLAGS] = "1"
 
+        # Record telemetry for successful injection
+        _record_http_telemetry("context_header_style.injected", PROPAGATION_STYLE_B3_MULTI)
+
     @staticmethod
     def _extract(headers):
         # type: (Dict[str, str]) -> Optional[Context]
@@ -561,6 +586,9 @@ class _B3SingleHeader:
                 single_header += "-d"
         headers[_HTTP_HEADER_B3_SINGLE] = single_header
 
+        # Record telemetry for successful injection
+        _record_http_telemetry("context_header_style.injected", PROPAGATION_STYLE_B3_SINGLE)
+
     @staticmethod
     def _extract(headers):
         # type: (Dict[str, str]) -> Optional[Context]
@@ -873,6 +901,9 @@ class _TraceContext:
             else:
                 headers[_HTTP_HEADER_TRACESTATE] = span_context._tracestate
 
+        # Record telemetry for successful injection
+        _record_http_telemetry("context_header_style.injected", _PROPAGATION_STYLE_W3C_TRACECONTEXT)
+
 
 class _BaggageHeader:
     """Helper class to inject/extract Baggage Headers"""
@@ -897,6 +928,13 @@ class _BaggageHeader:
         try:
             if len(baggage_items) > DD_TRACE_BAGGAGE_MAX_ITEMS:
                 log.warning("Baggage item limit exceeded, dropping excess items")
+                # Record telemetry for baggage item count exceeding limit
+                telemetry_writer.add_count_metric(
+                    namespace=TELEMETRY_NAMESPACE.TRACERS,
+                    name="context_header_style.truncated",
+                    value=1,
+                    tags=(("truncation_reason", "baggage_item_count_exceeded"),),
+                )
                 baggage_items = itertools.islice(baggage_items, DD_TRACE_BAGGAGE_MAX_ITEMS)  # type: ignore
 
             encoded_items: List[str] = []
@@ -906,6 +944,13 @@ class _BaggageHeader:
                 item_size = len(item.encode("utf-8")) + (1 if encoded_items else 0)  # +1 for comma if not first item
                 if total_size + item_size > DD_TRACE_BAGGAGE_MAX_BYTES:
                     log.warning("Baggage header size exceeded, dropping excess items")
+                    # Record telemetry for baggage header size exceeding limit
+                    telemetry_writer.add_count_metric(
+                        namespace=TELEMETRY_NAMESPACE.TRACERS,
+                        name="context_header_style.truncated",
+                        value=1,
+                        tags=(("truncation_reason", "baggage_byte_count_exceeded"),),
+                    )
                     break  # stop adding items when size limit is reached
                 encoded_items.append(item)
                 total_size += item_size
@@ -913,9 +958,23 @@ class _BaggageHeader:
             header_value = ",".join(encoded_items)
             headers[_HTTP_HEADER_BAGGAGE] = header_value
 
+            # Record telemetry for successful baggage injection
+            _record_http_telemetry("context_header_style.injected", _PROPAGATION_STYLE_BAGGAGE)
+
         except Exception:
             log.warning("Failed to encode and inject baggage header")
 
+    @staticmethod
+    def _record_malformed_and_return_empty() -> Context:
+        """Record telemetry for malformed baggage header and return empty context."""
+        telemetry_writer.add_count_metric(
+            namespace=TELEMETRY_NAMESPACE.TRACERS,
+            name="context_header_style.malformed",
+            value=1,
+            tags=(("header_style", _PROPAGATION_STYLE_BAGGAGE),),
+        )
+        return Context(baggage={})
+
     @staticmethod
     def _extract(headers: Dict[str, str]) -> Context:
         header_value = _extract_header_value(_POSSIBLE_HTTP_BAGGAGE_HEADER, headers)
@@ -927,12 +986,12 @@ class _BaggageHeader:
         baggages = header_value.split(",")
         for key_value in baggages:
             if "=" not in key_value:
-                return Context(baggage={})
+                return _BaggageHeader._record_malformed_and_return_empty()
             key, value = key_value.split("=", 1)
             key = urllib.parse.unquote(key.strip())
             value = urllib.parse.unquote(value.strip())
             if not key or not value:
-                return Context(baggage={})
+                return _BaggageHeader._record_malformed_and_return_empty()
             baggage[key] = value
 
         return Context(baggage=baggage)
@@ -952,6 +1011,47 @@ class HTTPPropagator(object):
     according to the propagation style set by ddtrace configurations.
     """
 
+    @staticmethod
+    def _get_sampled_injection_context(
+        trace_info: Union[Context, Span], non_active_span: Optional[Span] = None
+    ) -> Context:
+        """Handle sampling decision and return context for header injection.
+
+        If sampling_priority is already set, returns immediately. Otherwise, finds the
+        appropriate span and triggers sampling before returning the injection context.
+        """
+        # Extract context for header injection (non_active_span takes precedence)
+        injection_context = trace_info.context if isinstance(trace_info, Span) else trace_info
+
+        # Find root span for sampling decisions
+        if injection_context.sampling_priority is not None:
+            return injection_context
+        elif core.tracer is None:
+            # This should never happen, tracer should be initialized before headers can be injected.
+            log.error(
+                "No tracer found and injection context %s has no sampling priority, skipping sampling",
+                injection_context,
+            )
+            return injection_context
+
+        sampling_span: Optional[Span] = None
+        if non_active_span is not None:
+            # Deprecated: non_active_span takes precedence
+            sampling_span = non_active_span._local_root
+        elif isinstance(trace_info, Span):
+            # Use span's root for sampling
+            sampling_span = trace_info._local_root
+        elif (current_root := core.tracer.current_root_span()) and current_root.trace_id == trace_info.trace_id:
+            # Get the local root span for the current trace (if it is active, otherwise we can't sample)
+            sampling_span = current_root
+
+        # Sample the local root span before injecting headers.
+        if sampling_span:
+            core.tracer.sample(sampling_span)
+            log.debug("%s sampled before propagating trace: span_context=%s", sampling_span, injection_context)
+
+        return injection_context
+
     @staticmethod
     def _extract_configured_contexts_avail(normalized_headers: Dict[str, str]) -> Tuple[List[Context], List[str]]:
         contexts = []
@@ -964,6 +1064,7 @@ class HTTPPropagator(object):
                 propagator = _PROP_STYLES[prop_style]
                 context = propagator._extract(normalized_headers)  # type: ignore
                 if context:
+                    _record_http_telemetry("context_header_style.extracted", prop_style)
                     contexts.append(context)
                     styles_w_ctx.append(prop_style)
         return contexts, styles_w_ctx
@@ -1026,8 +1127,7 @@ class HTTPPropagator(object):
         return primary_context
 
     @staticmethod
-    def inject(span_context, headers, non_active_span=None):
-        # type: (Context, Dict[str, str], Optional[Span]) -> None
+    def inject(context: Union[Context, Span], headers: Dict[str, str], non_active_span: Optional[Span] = None) -> None:
         """Inject Context attributes that have to be propagated as HTTP headers.
 
         Here is an example using `requests`::
@@ -1037,40 +1137,51 @@ class HTTPPropagator(object):
             from ddtrace.propagation.http import HTTPPropagator
 
             def parent_call():
-                with tracer.trace('parent_span') as span:
+                with tracer.start_span('parent_span') as span:
                     headers = {}
+                    # Preferred: Pass span object to context argument
+                    HTTPPropagator.inject(span, headers)
+                    url = '<some RPC endpoint>'
+                    r = requests.get(url, headers=headers)
+
+                with tracer.start_span('child_span2') as span:
+                    headers = {}
+                    # Alternative: Pass context, but ensure sampling_priority is set
+                    tracer.sample(span)
                     HTTPPropagator.inject(span.context, headers)
                     url = '<some RPC endpoint>'
                     r = requests.get(url, headers=headers)
 
-        :param Context span_context: Span context to propagate.
+        :param Union[Span, Context] context: Pass a Span object (preferred) or Context object.
+            Span objects automatically trigger sampling decisions. Context objects should have
+            sampling_priority set to avoid inconsistent downstream sampling.
         :param dict headers: HTTP headers to extend with tracing attributes.
-        :param Span non_active_span: Only to be used if injecting a non-active span.
+        :param Span non_active_span: **DEPRECATED** - Pass Span objects to the context parameter instead.
         """
+        if non_active_span is not None:
+            # non_active_span is only used for sampling decisions, not to inject headers.
+            deprecate(
+                "The non_active_span parameter is deprecated",
+                message="Use the context parameter instead.",
+                category=DDTraceDeprecationWarning,
+                removal_version="4.0.0",
+            )
+        # Cannot rename context parameter due to backwards compatibility
+        # Handle sampling and get context for header injection
+        span_context = HTTPPropagator._get_sampled_injection_context(context, non_active_span)
+        # Log a warning if we cannot determine a sampling decision before injecting headers.
+        if span_context.span_id and span_context.trace_id and span_context.sampling_priority is None:
+            log.debug(
+                "Sampling decision not available. Downstream spans will not inherit a sampling priority: "
+                "args=(context=%s, ..., non_active_span=%s) detected span context=%s",
+                context,
+                non_active_span,
+                span_context,
+            )
+
         core.dispatch("http.span_inject", (span_context, headers))
         if not config._propagation_style_inject:
             return
-        if non_active_span is not None and non_active_span.context is not span_context:
-            log.error(
-                "span_context and non_active_span.context are not the same, but should be. non_active_span.context "
-                "will be used to generate distributed tracing headers. span_context: {}, non_active_span.context: {}",
-                span_context,
-                non_active_span.context,
-            )
-
-            span_context = non_active_span.context
-
-        if core.tracer and hasattr(core.tracer, "sample"):
-            root_span: Optional[Span] = None
-            if non_active_span is not None:
-                root_span = non_active_span._local_root
-            else:
-                root_span = core.tracer.current_root_span()
-
-            if root_span is not None and root_span.context.sampling_priority is None:
-                core.tracer.sample(root_span)
-        else:
-            log.error("ddtrace.tracer.sample is not available, unable to sample span.")
 
         # baggage should be injected regardless of existing span or trace id
         if _PROPAGATION_STYLE_BAGGAGE in config._propagation_style_inject:
@@ -1130,6 +1241,8 @@ class HTTPPropagator(object):
                     propagator = _PROP_STYLES[prop_style]
                     context = propagator._extract(normalized_headers)
                     style = prop_style
+                    if context:
+                        _record_http_telemetry("context_header_style.extracted", prop_style)
                     if config._propagation_http_baggage_enabled is True:
                         _attach_baggage_to_context(normalized_headers, context)
                     break
@@ -1150,6 +1263,8 @@ class HTTPPropagator(object):
             if _PROPAGATION_STYLE_BAGGAGE in config._propagation_style_extract:
                 baggage_context = _BaggageHeader._extract(normalized_headers)
                 if baggage_context._baggage != {}:
+                    # Record telemetry for successful baggage extraction
+                    _record_http_telemetry("context_header_style.extracted", _PROPAGATION_STYLE_BAGGAGE)
                     if context:
                         context._baggage = baggage_context.get_all_baggage_items()
                     else:
