@@ -12,6 +12,7 @@ from ddtrace.appsec._constants import DEFAULT
 from ddtrace.appsec._constants import FINGERPRINTING
 from ddtrace.appsec._constants import WAF_DATA_NAMES
 from ddtrace.appsec._ddwaf import DDWaf
+from ddtrace.appsec._ddwaf.ddwaf_types import py_ddwaf_builder_get_config_paths
 from ddtrace.appsec._processor import AppSecSpanProcessor
 from ddtrace.appsec._processor import _transform_headers
 from ddtrace.appsec._utils import get_triggers
@@ -232,25 +233,28 @@ def test_ip_not_block(tracer, ip):
 
 def test_ip_update_rules_and_block(tracer):
     with asm_context(tracer=tracer, ip_addr=rules._IP.BLOCKED, config=config_asm) as span1:
-        tracer._appsec_processor._update_rules(
-            [],
-            [
-                (
-                    "ASM",
-                    "Datadog/1/ASM/data",
-                    {
-                        "rules_data": [
-                            {
-                                "data": [
-                                    {"value": rules._IP.BLOCKED},
-                                ],
-                                "id": "blocked_ips",
-                                "type": "ip_with_expiration",
-                            },
-                        ]
-                    },
-                )
-            ],
+        core.dispatch(
+            "waf.update",
+            (
+                [],
+                [
+                    (
+                        "ASM",
+                        "Datadog/1/ASM/data",
+                        {
+                            "rules_data": [
+                                {
+                                    "data": [
+                                        {"value": rules._IP.BLOCKED},
+                                    ],
+                                    "id": "blocked_ips",
+                                    "type": "ip_with_expiration",
+                                },
+                            ]
+                        },
+                    )
+                ],
+            ),
         )
         with tracer.trace("test", span_type=SpanTypes.WEB) as span:
             set_http_meta(
@@ -262,28 +266,36 @@ def test_ip_update_rules_and_block(tracer):
     assert is_blocked(span1)
     assert (span._local_root or span).get_tag(APPSEC.RC_PRODUCTS) == "[ASM:1] u:1 r:2"
 
+    from ddtrace.appsec._processor import AppSecSpanProcessor
+
+    assert AppSecSpanProcessor._instance
+    assert py_ddwaf_builder_get_config_paths(AppSecSpanProcessor._instance._ddwaf._builder, "ASM/data") == 1
+
 
 def test_ip_update_rules_expired_no_block(tracer):
     with asm_context(tracer=tracer, ip_addr=rules._IP.BLOCKED, config=config_asm):
-        tracer._appsec_processor._update_rules(
-            [],
-            [
-                (
-                    "ASM",
-                    "Datadog/1/ASM/data",
-                    {
-                        "rules_data": [
-                            {
-                                "data": [
-                                    {"expiration": 1662804872, "value": rules._IP.BLOCKED},
-                                ],
-                                "id": "blocked_ips",
-                                "type": "ip_with_expiration",
-                            },
-                        ]
-                    },
-                )
-            ],
+        core.dispatch(
+            "waf.update",
+            (
+                [],
+                [
+                    (
+                        "ASM",
+                        "Datadog/1/ASM/data",
+                        {
+                            "rules_data": [
+                                {
+                                    "data": [
+                                        {"expiration": 1662804872, "value": rules._IP.BLOCKED},
+                                    ],
+                                    "id": "blocked_ips",
+                                    "type": "ip_with_expiration",
+                                },
+                            ]
+                        },
+                    )
+                ],
+            ),
         )
         with tracer.trace("test", span_type=SpanTypes.WEB) as span:
             set_http_meta(
@@ -367,10 +379,10 @@ def test_appsec_span_rate_limit(tracer):
 
 
 def test_ddwaf_not_raises_exception():
-    with open(DEFAULT.RULES) as rules:
-        rules_json = json.loads(rules.read())
+    with open(DEFAULT.RULES, "br") as rules:
+        rules_json_str = rules.read()
         DDWaf(
-            rules_json,
+            rules_json_str,
             DEFAULT.APPSEC_OBFUSCATION_PARAMETER_KEY_REGEXP.encode("utf-8"),
             DEFAULT.APPSEC_OBFUSCATION_PARAMETER_VALUE_REGEXP.encode("utf-8"),
             _metrics,
@@ -500,9 +512,9 @@ def test_obfuscation_parameter_value_configured_matching(tracer):
 
 
 def test_ddwaf_run():
-    with open(rules.RULES_GOOD_PATH) as rule_set:
-        rules_json = json.loads(rule_set.read())
-        _ddwaf = DDWaf(rules_json, b"", b"", _metrics)
+    with open(rules.RULES_GOOD_PATH, "br") as rule_set:
+        rules_json_str = rule_set.read()
+        _ddwaf = DDWaf(rules_json_str, b"", b"", _metrics)
         data = {
             "server.request.query": {},
             "server.request.headers.no_cookies": {"user-agent": "werkzeug/2.1.2", "host": "localhost"},
@@ -520,8 +532,8 @@ def test_ddwaf_run():
 
 
 def test_ddwaf_run_timeout():
-    with open(rules.RULES_GOOD_PATH) as rule_set:
-        rules_json = json.loads(rule_set.read())
+    with open(rules.RULES_GOOD_PATH, "br") as rule_set:
+        rules_json = rule_set.read()
         _ddwaf = DDWaf(rules_json, b"", b"", _metrics)
         data = {
             "server.request.path_params": {"param_{}".format(i): "value_{}".format(i) for i in range(100)},
@@ -536,11 +548,12 @@ def test_ddwaf_run_timeout():
 
 
 def test_ddwaf_info():
-    with open(rules.RULES_GOOD_PATH) as rule_set:
-        rules_json = json.loads(rule_set.read())
-        _ddwaf = DDWaf(rules_json, b"", b"", _metrics)
+    with open(rules.RULES_GOOD_PATH, "br") as rule_set:
+        rules_json_str = rule_set.read()
+        _ddwaf = DDWaf(rules_json_str, b"", b"", _metrics)
 
         info = _ddwaf.info
+        rules_json = json.loads(rules_json_str.decode())
         assert info.loaded == len(rules_json["rules"])
         assert info.failed == 0
         assert info.errors == ""
@@ -548,9 +561,9 @@ def test_ddwaf_info():
 
 
 def test_ddwaf_info_with_2_errors():
-    with open(os.path.join(rules.ROOT_DIR, "rules-with-2-errors.json")) as rule_set:
-        rules_json = json.loads(rule_set.read())
-        _ddwaf = DDWaf(rules_json, b"", b"", _metrics)
+    with open(os.path.join(rules.ROOT_DIR, "rules-with-2-errors.json"), "br") as rule_set:
+        rules_json_str = rule_set.read()
+        _ddwaf = DDWaf(rules_json_str, b"", b"", _metrics)
 
         info = _ddwaf.info
         assert info.loaded == 1
@@ -564,9 +577,9 @@ def test_ddwaf_info_with_2_errors():
 
 
 def test_ddwaf_info_with_3_errors():
-    with open(os.path.join(rules.ROOT_DIR, "rules-with-3-errors.json")) as rule_set:
-        rules_json = json.loads(rule_set.read())
-        _ddwaf = DDWaf(rules_json, b"", b"", _metrics)
+    with open(os.path.join(rules.ROOT_DIR, "rules-with-3-errors.json"), "br") as rule_set:
+        rules_json_str = rule_set.read()
+        _ddwaf = DDWaf(rules_json_str, b"", b"", _metrics)
 
         info = _ddwaf.info
         assert info.loaded == 1
@@ -752,7 +765,7 @@ def test_ephemeral_addresses(mock_run, persistent, ephemeral):
     mock_run.return_value = DDWaf_result(0, [], {}, 0.0, 0.0, False, _observator(), {})
 
     with asm_context(tracer=tracer, config=config_asm, rc_payload=CUSTOM_RULE_METHOD) as span:
-        processor = tracer._appsec_processor
+        processor = AppSecSpanProcessor._instance
         assert processor
         # first call must send all data to the waf
         processor._waf_action(span, None, {persistent: {"key_1": "value_1"}, ephemeral: {"key_2": "value_2"}})
@@ -765,3 +778,28 @@ def test_ephemeral_addresses(mock_run, persistent, ephemeral):
             WAF_DATA_NAMES[ephemeral]: {"key_2": "value_3"},
         }
     assert (span._local_root or span).get_tag(APPSEC.RC_PRODUCTS) == "[ASM:1] u:1 r:1"
+
+
+@pytest.mark.parametrize("skip_event", [True, False])
+def test_lambda_unsupported_event(tracer, skip_event):
+    """
+    Test that the processor correctly handles the appsec_skip_next_lambda_event flag.
+    """
+    if skip_event:
+        core.set_item("appsec_skip_next_lambda_event", True)
+
+    config = {
+        "_asm_enabled": True,
+        "_asm_processed_span_types": {SpanTypes.SERVERLESS},
+    }
+
+    with asm_context(tracer=tracer, config=config, span_type=SpanTypes.SERVERLESS) as span:
+        pass
+
+    if skip_event:
+        # When skip_event is True, the metric should be set and context item should be discarded
+        assert span.get_metric(APPSEC.UNSUPPORTED_EVENT_TYPE) == 1.0
+        assert core.get_item("appsec_skip_next_lambda_event") is None
+    else:
+        # When skip_event is False, the metric should not be set
+        assert span.get_metric(APPSEC.UNSUPPORTED_EVENT_TYPE) is None
