@@ -23,6 +23,7 @@ from ddtrace.appsec._iast.taint_sinks.xss import patch as patch_xss_injection
 from ddtrace.contrib.internal.sqlite3.patch import patch as patch_sqlite_sqli
 from ddtrace.settings.asm import config as asm_config
 from tests.appsec.iast.iast_utils import get_line_and_hash
+from tests.appsec.iast.iast_utils import load_iast_report
 from tests.appsec.integrations.flask_tests.utils import flask_version
 from tests.appsec.integrations.flask_tests.utils import werkzeug_version
 from tests.contrib.flask import BaseFlaskTestCase
@@ -85,7 +86,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.path.parameter", "name": "param_str", "value": "sqlite_master"}
             ]
@@ -140,7 +141,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.header", "name": "User-Agent", "value": "sqlite_master"}
             ]
@@ -198,7 +199,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.header", "name": "User-Agent", "value": "sqlite_master"}
             ]
@@ -257,7 +258,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"origin": "http.request.header.name", "name": "Master", "value": "Master"}]
 
             line, hash_value = get_line_and_hash(
@@ -311,7 +312,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"origin": "http.request.header", "name": "User-Agent", "value": "master"}]
 
             line, hash_value = get_line_and_hash(
@@ -452,7 +453,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.cookie.value", "name": "test-cookie1", "value": "sqlite_master"}
             ]
@@ -518,7 +519,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.cookie.name", "name": "sqlite_master", "value": "sqlite_master"}
             ]
@@ -576,7 +577,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "table", "value": "sqlite_master"}
             ]
@@ -633,7 +634,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter.name", "name": "sqlite_master", "value": "sqlite_master"}
             ]
@@ -692,7 +693,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter.name", "name": "sqlite_master", "value": "sqlite_master"}
             ]
@@ -760,7 +761,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"name": "json_body", "origin": "http.request.body", "value": "master"}]
 
             line, hash_value = get_line_and_hash(
@@ -826,7 +827,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"name": "body3", "origin": "http.request.body", "value": "master"}]
 
             line, hash_value = get_line_and_hash(
@@ -892,7 +893,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"name": "body3", "origin": "http.request.body", "value": "master"}]
 
             line, hash_value = get_line_and_hash(
@@ -960,7 +961,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"name": "body4", "origin": "http.request.body", "value": "master"}]
 
             line, hash_value = get_line_and_hash(
@@ -1099,7 +1100,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"name": "extra", "origin": "http.request.body", "value": "master"}]
 
             line, hash_value = get_line_and_hash(
@@ -1170,7 +1171,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"name": "json_body", "origin": "http.request.body", "value": "master"}]
 
             list_metrics_logs = list(self._telemetry_writer._logs)
@@ -1207,7 +1208,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [{"origin": "http.request.header", "name": "User-Agent", "value": "master"}]
 
             line, hash_value = get_line_and_hash(
@@ -1271,7 +1272,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
 
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     def test_flask_header_injection_direct_access_to_header(self):
         @self.app.route("/header_injection_insecure/", methods=["GET", "POST"])
@@ -1298,7 +1299,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     def test_flask_header_injection_direct_access_to_header_exception(self):
         @self.app.route("/header_injection_insecure/", methods=["GET", "POST"])
@@ -1329,7 +1330,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
 
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
     def test_flask_header_injection_exclusions_transfer_encoding(self):
@@ -1356,7 +1357,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
     def test_flask_header_injection_exclusions_access_control(self):
@@ -1383,7 +1384,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
     def test_flask_insecure_cookie(self):
@@ -1412,7 +1413,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == []
             assert len(loaded["vulnerabilities"]) == 1
             vulnerability = loaded["vulnerabilities"][0]
@@ -1453,7 +1454,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = root_span.get_tag(IAST.JSON)
+            loaded = load_iast_report(root_span)
             assert loaded is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1483,7 +1484,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == []
             assert len(loaded["vulnerabilities"]) == 1
             vulnerability = loaded["vulnerabilities"][0]
@@ -1523,7 +1524,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = root_span.get_tag(IAST.JSON)
+            loaded = load_iast_report(root_span)
             assert loaded is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1553,7 +1554,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == []
             assert len(loaded["vulnerabilities"]) == 1
             vulnerability = loaded["vulnerabilities"][0]
@@ -1591,7 +1592,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             assert resp.status_code == 200
 
             root_span = self.pop_spans()[0]
-            loaded = root_span.get_tag(IAST.JSON)
+            loaded = load_iast_report(root_span)
             assert loaded is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1620,7 +1621,7 @@ class FlaskAppSecIASTEnabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = root_span.get_tag(IAST.JSON)
+            loaded = load_iast_report(root_span)
             assert loaded is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
@@ -1667,7 +1668,7 @@ Lorem Ipsum Foobar
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == []
             assert len(loaded["vulnerabilities"]) == 1
             vulnerability = loaded["vulnerabilities"][0]
@@ -1713,7 +1714,7 @@ Lorem Ipsum Foobar
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == []
             assert len(loaded["vulnerabilities"]) == 1
             vulnerability = loaded["vulnerabilities"][0]
@@ -1750,7 +1751,7 @@ Lorem Ipsum Foobar
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "input", "value": "<script>alert('XSS')</script>"}
             ]
@@ -1793,7 +1794,7 @@ Lorem Ipsum Foobar
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "url", "value": "http://localhost:8080/malicious"}
             ]
@@ -1837,7 +1838,7 @@ Lorem Ipsum Foobar
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "url", "value": "http://localhost:8080/malicious"}
             ]
@@ -1876,7 +1877,7 @@ Lorem Ipsum Foobar
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "input", "value": "<script>alert('XSS')</script>"}
             ]
@@ -1921,7 +1922,7 @@ Lorem Ipsum Foobar
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     def test_flask_xss_template(self):
         @self.app.route("/xss/template/", methods=["GET"])
@@ -1948,7 +1949,7 @@ Lorem Ipsum Foobar
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) == 1.0
 
-            loaded = json.loads(root_span.get_tag(IAST.JSON))
+            loaded = load_iast_report(root_span)
             assert loaded["sources"] == [
                 {"origin": "http.request.parameter", "name": "input", "value": "<script>alert('XSS')</script>"}
             ]
@@ -2009,10 +2010,9 @@ Lorem Ipsum Foobar
 
                 root_span = self.pop_spans()[0]
                 assert str(resp.data, encoding="utf-8") == f"OK:value{i}", resp.data
-                iast_data = root_span.get_tag(IAST.JSON)
+                loaded = load_iast_report(root_span)
                 if i < 8:
-                    assert iast_data, f"No data({i}): {iast_data}"
-                    loaded = json.loads(iast_data)
+                    assert loaded, f"No data({i}): {loaded}"
                     assert len(loaded["vulnerabilities"]) == 2
                     assert loaded["sources"] == [
                         {"origin": "http.request.parameter", "name": "param", "redacted": True, "pattern": "abcdef"}
@@ -2021,7 +2021,7 @@ Lorem Ipsum Foobar
                         assert vuln["type"] == VULN_SQL_INJECTION
                         list_vulnerabilities.append(vuln["location"]["line"])
                 else:
-                    assert iast_data is None
+                    assert loaded is None
             assert (
                 len(list_vulnerabilities) == 16
             ), f"Num vulnerabilities: ({len(list_vulnerabilities)}): {list_vulnerabilities}"
@@ -2073,7 +2073,7 @@ class FlaskAppSecIASTDisabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) is None
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
     def test_flask_full_sqli_iast_disabled_http_request_header_getitem(self):
@@ -2105,7 +2105,7 @@ class FlaskAppSecIASTDisabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) is None
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
     def test_flask_full_sqli_iast_disabled_http_request_header_name_keys(self):
@@ -2137,7 +2137,7 @@ class FlaskAppSecIASTDisabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) is None
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
     def test_flask_full_sqli_iast_disabled_http_request_header_values(self):
@@ -2169,7 +2169,7 @@ class FlaskAppSecIASTDisabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) is None
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
 
     @pytest.mark.skipif(not asm_config._iast_supported, reason="Python version not supported by IAST")
     def test_flask_simple_iast_path_header_and_querystring_not_tainted_if_iast_disabled(self):
@@ -2228,4 +2228,4 @@ class FlaskAppSecIASTDisabledTestCase(BaseFlaskTestCase):
             root_span = self.pop_spans()[0]
             assert root_span.get_metric(IAST.ENABLED) is None
 
-            assert root_span.get_tag(IAST.JSON) is None
+            assert load_iast_report(root_span) is None
