@@ -25,41 +25,41 @@ from tests.utils import override_global_config
 )
 class TestLLMObsBedrock:
     @staticmethod
-    def expected_llmobs_span_event(span, n_output, message=False):
-        prompt_tokens = span.get_metric("bedrock.response.usage.prompt_tokens")
-        completion_tokens = span.get_metric("bedrock.response.usage.completion_tokens")
-        token_metrics = {}
-        if prompt_tokens is not None:
-            token_metrics["input_tokens"] = prompt_tokens
-        if completion_tokens is not None:
-            token_metrics["output_tokens"] = completion_tokens
-        if prompt_tokens is not None and completion_tokens is not None:
-            token_metrics["total_tokens"] = prompt_tokens + completion_tokens
-
-        if span.get_tag("bedrock.request.temperature"):
-            expected_parameters = {"temperature": float(span.get_tag("bedrock.request.temperature"))}
-        if span.get_tag("bedrock.request.max_tokens"):
-            expected_parameters["max_tokens"] = int(span.get_tag("bedrock.request.max_tokens"))
-
+    def expected_llmobs_span_event(span, n_output, message=False, metadata=None, token_metrics=None):
         expected_input = [{"content": mock.ANY}]
         if message:
             expected_input = [{"content": mock.ANY, "role": "user"}]
-        return _expected_llmobs_llm_span_event(
+
+        # Use empty dicts as defaults for _expected_llmobs_llm_span_event to avoid None issues
+        expected_parameters = metadata if metadata is not None else {}
+        expected_token_metrics = token_metrics if token_metrics is not None else None
+
+        expected_event = _expected_llmobs_llm_span_event(
             span,
             model_name=span.get_tag("bedrock.request.model"),
             model_provider=span.get_tag("bedrock.request.model_provider"),
             input_messages=expected_input,
             output_messages=[{"content": mock.ANY} for _ in range(n_output)],
             metadata=expected_parameters,
-            token_metrics=token_metrics,
+            token_metrics=expected_token_metrics,
             tags={"service": "aws.bedrock-runtime", "ml_app": "<ml-app-name>"},
         )
 
+        # If parameters were not explicitly provided, use mock.ANY to match anything
+        if metadata is None:
+            expected_event["meta"]["metadata"] = mock.ANY
+        if token_metrics is None:
+            expected_event["metrics"] = mock.ANY
+
+        return expected_event
+
     @classmethod
     def _test_llmobs_invoke(cls, provider, bedrock_client, mock_tracer, llmobs_events, cassette_name=None, n_output=1):
         if cassette_name is None:
             cassette_name = "%s_invoke.yaml" % provider
         body = _REQUEST_BODIES[provider]
+        expected_metadata = None
+
         if provider == "cohere":
             body = {
                 "prompt": "\n\nHuman: %s\n\nAssistant: Can you explain what a LLM chain is?",
@@ -71,6 +71,8 @@ class TestLLMObsBedrock:
                 "stream": False,
                 "num_generations": n_output,
             }
+            expected_metadata = {"temperature": 0.9, "max_tokens": 10}
+
         with get_request_vcr().use_cassette(cassette_name):
             body, model = json.dumps(body), _MODELS[provider]
             if provider == "anthropic_message":
@@ -82,7 +84,9 @@ class TestLLMObsBedrock:
         span = mock_tracer.pop_traces()[0][0]
 
         assert len(llmobs_events) == 1
-        assert llmobs_events[0] == cls.expected_llmobs_span_event(span, n_output, message="message" in provider)
+        assert llmobs_events[0] == cls.expected_llmobs_span_event(
+            span, n_output, message="message" in provider, metadata=expected_metadata
+        )
         LLMObs.disable()
 
     @classmethod
@@ -92,6 +96,8 @@ class TestLLMObsBedrock:
         if cassette_name is None:
             cassette_name = "%s_invoke_stream.yaml" % provider
         body = _REQUEST_BODIES[provider]
+        expected_metadata = None
+
         if provider == "cohere":
             body = {
                 "prompt": "\n\nHuman: %s\n\nAssistant: Can you explain what a LLM chain is?",
@@ -103,6 +109,8 @@ class TestLLMObsBedrock:
                 "stream": True,
                 "num_generations": n_output,
             }
+            expected_metadata = {"temperature": 0.9, "max_tokens": 10}
+
         with get_request_vcr().use_cassette(cassette_name):
             body, model = json.dumps(body), _MODELS[provider]
             response = bedrock_client.invoke_model_with_response_stream(body=body, modelId=model)
@@ -111,7 +119,9 @@ class TestLLMObsBedrock:
         span = mock_tracer.pop_traces()[0][0]
 
         assert len(llmobs_events) == 1
-        assert llmobs_events[0] == cls.expected_llmobs_span_event(span, n_output, message="message" in provider)
+        assert llmobs_events[0] == cls.expected_llmobs_span_event(
+            span, n_output, message="message" in provider, metadata=expected_metadata
+        )
 
     def test_llmobs_ai21_invoke(self, ddtrace_global_config, bedrock_client, mock_tracer, llmobs_events):
         self._test_llmobs_invoke("ai21", bedrock_client, mock_tracer, llmobs_events)
@@ -216,16 +226,15 @@ class TestLLMObsBedrock:
                 json.loads(response.get("body").read())
         span = mock_tracer.pop_traces()[0][0]
 
+        metadata = mock.ANY
+
         assert len(llmobs_events) == 1
         assert llmobs_events[0] == _expected_llmobs_llm_span_event(
             span,
             model_name=span.get_tag("bedrock.request.model"),
             model_provider=span.get_tag("bedrock.request.model_provider"),
             input_messages=[{"content": mock.ANY}],
-            metadata={
-                "temperature": float(span.get_tag("bedrock.request.temperature")),
-                "max_tokens": int(span.get_tag("bedrock.request.max_tokens")),
-            },
+            metadata=metadata,
             output_messages=[{"content": ""}],
             error=span.get_tag("error.type"),
             error_message=span.get_tag("error.message"),
@@ -405,6 +414,233 @@ class TestLLMObsBedrock:
             tags={"service": "aws.bedrock-runtime", "ml_app": "<ml-app-name>"},
         )
 
+    @pytest.mark.skipif(BOTO_VERSION < (1, 34, 131), reason="Converse API not available until botocore 1.34.131")
+    def test_llmobs_converse_prompt_caching(self, bedrock_client, request_vcr, mock_tracer, llmobs_events):
+        """Test that prompt caching metrics are properly captured for both cache creation and cache read."""
+        large_system_prompt = "Software architecture guidelines: " + "bye " * 1024
+        large_system_content = [
+            {"text": large_system_prompt},
+            {"cachePoint": {"type": "default"}},
+        ]
+        with request_vcr.use_cassette("bedrock_converse_prompt_caching.yaml"):
+            _, _ = bedrock_client.converse(
+                **create_bedrock_converse_request(
+                    system=large_system_content,
+                    user_message="What is a service",
+                    modelId="us.anthropic.claude-3-7-sonnet-20250219-v1:0",
+                )
+            ), bedrock_client.converse(
+                **create_bedrock_converse_request(
+                    system=large_system_content,
+                    user_message="What is a ml app",
+                    modelId="us.anthropic.claude-3-7-sonnet-20250219-v1:0",
+                )
+            )
+            assert len(llmobs_events) == 2
+            spans = mock_tracer.pop_traces()
+            span1, span2 = spans[0][0], spans[1][0]
+            assert llmobs_events[0] == _expected_llmobs_llm_span_event(
+                span1,
+                model_name="claude-3-7-sonnet-20250219-v1:0",
+                model_provider="anthropic",
+                input_messages=[
+                    {"role": "system", "content": large_system_prompt},
+                    {"role": "system", "content": "[Unsupported content type: cachePoint]"},
+                    {"role": "user", "content": "What is a service"},
+                ],
+                output_messages=[{"role": "assistant", "content": mock.ANY}],
+                metadata={
+                    "max_tokens": 1000,
+                    "stop_reason": "end_turn",
+                    "temperature": 0.7,
+                },
+                token_metrics={
+                    "input_tokens": 1039,
+                    "output_tokens": 264,
+                    "total_tokens": 1303,
+                    "cache_write_input_tokens": 1028,
+                    "cache_read_input_tokens": 0,
+                },
+                tags={"service": "aws.bedrock-runtime", "ml_app": "<ml-app-name>"},
+            )
+            assert llmobs_events[1] == _expected_llmobs_llm_span_event(
+                span2,
+                model_name="claude-3-7-sonnet-20250219-v1:0",
+                model_provider="anthropic",
+                input_messages=[
+                    {"role": "system", "content": large_system_prompt},
+                    {"role": "system", "content": "[Unsupported content type: cachePoint]"},
+                    {"role": "user", "content": "What is a ml app"},
+                ],
+                output_messages=[{"role": "assistant", "content": mock.ANY}],
+                metadata={
+                    "max_tokens": 1000,
+                    "stop_reason": "end_turn",
+                    "temperature": 0.7,
+                },
+                token_metrics={
+                    "input_tokens": 1040,
+                    "output_tokens": 185,
+                    "total_tokens": 1225,
+                    "cache_write_input_tokens": 0,
+                    "cache_read_input_tokens": 1028,
+                },
+                tags={"service": "aws.bedrock-runtime", "ml_app": "<ml-app-name>"},
+            )
+
+    @pytest.mark.skipif(BOTO_VERSION < (1, 34, 131), reason="Converse API not available until botocore 1.34.131")
+    def test_llmobs_converse_stream_prompt_caching(self, bedrock_client, request_vcr, mock_tracer, llmobs_events):
+        """Test that prompt caching metrics are properly captured for streamed converse responses."""
+        large_system_prompt = "Software architecture guidelines: " + "hello " * 1024
+        large_system_content = [
+            {"text": large_system_prompt},
+            {"cachePoint": {"type": "default"}},
+        ]
+        with request_vcr.use_cassette("bedrock_converse_stream_prompt_caching.yaml"):
+            stream_1 = bedrock_client.converse_stream(
+                **create_bedrock_converse_request(
+                    system=large_system_content,
+                    user_message="What is a service",
+                    modelId="us.anthropic.claude-3-7-sonnet-20250219-v1:0",
+                )
+            )
+            for _ in stream_1["stream"]:
+                pass
+            stream_2 = bedrock_client.converse_stream(
+                **create_bedrock_converse_request(
+                    system=large_system_content,
+                    user_message="What is a ml app",
+                    modelId="us.anthropic.claude-3-7-sonnet-20250219-v1:0",
+                )
+            )
+            for _ in stream_2["stream"]:
+                pass
+
+            assert len(llmobs_events) == 2
+            spans = mock_tracer.pop_traces()
+            span1, span2 = spans[0][0], spans[1][0]
+
+            assert llmobs_events[0] == _expected_llmobs_llm_span_event(
+                span1,
+                model_name="claude-3-7-sonnet-20250219-v1:0",
+                model_provider="anthropic",
+                input_messages=[
+                    {"content": large_system_prompt, "role": "system"},
+                    {"role": "system", "content": "[Unsupported content type: cachePoint]"},
+                    {"content": "What is a service", "role": "user"},
+                ],
+                output_messages=[{"content": mock.ANY, "role": "assistant"}],
+                metadata={
+                    "max_tokens": 1000,
+                    "temperature": 0.7,
+                },
+                token_metrics={
+                    "input_tokens": 1039,
+                    "output_tokens": 236,
+                    "total_tokens": 1275,
+                    "cache_write_input_tokens": 1028,
+                    "cache_read_input_tokens": 0,
+                },
+                tags={"service": "aws.bedrock-runtime", "ml_app": "<ml-app-name>"},
+            )
+            assert llmobs_events[1] == _expected_llmobs_llm_span_event(
+                span2,
+                model_name="claude-3-7-sonnet-20250219-v1:0",
+                model_provider="anthropic",
+                input_messages=[
+                    {"content": large_system_prompt, "role": "system"},
+                    {"role": "system", "content": "[Unsupported content type: cachePoint]"},
+                    {"content": "What is a ml app", "role": "user"},
+                ],
+                output_messages=[{"content": mock.ANY, "role": "assistant"}],
+                metadata={
+                    "max_tokens": 1000,
+                    "temperature": 0.7,
+                },
+                token_metrics={
+                    "input_tokens": 1040,
+                    "output_tokens": 250,
+                    "total_tokens": 1290,
+                    "cache_write_input_tokens": 0,
+                    "cache_read_input_tokens": 1028,
+                },
+                tags={"service": "aws.bedrock-runtime", "ml_app": "<ml-app-name>"},
+            )
+
+    @pytest.mark.skipif(BOTO_VERSION < (1, 34, 131), reason="Converse API not available until botocore 1.34.131")
+    def test_llmobs_converse_tool_result_text(self, bedrock_client, request_vcr, mock_tracer, llmobs_events):
+        import botocore
+
+        with pytest.raises(botocore.exceptions.ClientError):
+            bedrock_client.converse(
+                modelId="anthropic.claude-3-sonnet-20240229-v1:0",
+                inferenceConfig={"temperature": 0.7, "topP": 0.9, "maxTokens": 1000, "stopSequences": []},
+                messages=[
+                    {"role": "user", "content": [{"toolResult": {"toolUseId": "foo", "content": [{"text": "bar"}]}}]}
+                ],
+            )
+
+        assert len(llmobs_events) == 1
+        assert llmobs_events[0]["meta"]["input"]["messages"] == [{"content": "bar", "role": "tool", "tool_id": "foo"}]
+
+    @pytest.mark.skipif(BOTO_VERSION < (1, 34, 131), reason="Converse API not available until botocore 1.34.131")
+    def test_llmobs_converse_tool_result_json(self, bedrock_client, request_vcr, mock_tracer, llmobs_events):
+        import botocore
+
+        with pytest.raises(botocore.exceptions.ClientError):
+            bedrock_client.converse(
+                modelId="anthropic.claude-3-sonnet-20240229-v1:0",
+                inferenceConfig={"temperature": 0.7, "topP": 0.9, "maxTokens": 1000, "stopSequences": []},
+                messages=[
+                    {
+                        "role": "user",
+                        "content": [{"toolResult": {"toolUseId": "foo", "content": [{"json": {"result": "bar"}}]}}],
+                    }
+                ],
+            )
+
+        assert len(llmobs_events) == 1
+        assert llmobs_events[0]["meta"]["input"]["messages"] == [
+            {"content": '{"result": "bar"}', "role": "tool", "tool_id": "foo"}
+        ]
+
+    @pytest.mark.skipif(BOTO_VERSION < (1, 34, 131), reason="Converse API not available until botocore 1.34.131")
+    def test_llmobs_converse_tool_result_json_non_text_or_json(
+        self, bedrock_client, request_vcr, mock_tracer, llmobs_events
+    ):
+        import botocore
+
+        with pytest.raises(botocore.exceptions.ClientError):
+            bedrock_client.converse(
+                modelId="anthropic.claude-3-sonnet-20240229-v1:0",
+                inferenceConfig={"temperature": 0.7, "topP": 0.9, "maxTokens": 1000, "stopSequences": []},
+                messages=[
+                    {
+                        "role": "user",
+                        "content": [
+                            {
+                                "toolResult": {
+                                    "toolUseId": "foo",
+                                    "content": [
+                                        {
+                                            "image": {
+                                                "format": "png",
+                                                "source": {"s3Location": {"uri": "s3://bucket/key"}},
+                                            }
+                                        }
+                                    ],
+                                }
+                            }
+                        ],
+                    }
+                ],
+            )
+
+        assert len(llmobs_events) == 1
+        assert llmobs_events[0]["meta"]["input"]["messages"] == [
+            {"content": "[Unsupported content type(s): image]", "role": "tool", "tool_id": "foo"}
+        ]
+
 
 @pytest.mark.parametrize(
     "ddtrace_global_config",
@@ -420,11 +656,8 @@ class TestLLMObsBedrock:
 )
 class TestLLMObsBedrockProxy:
     @staticmethod
-    def expected_llmobs_span_event_proxy(span, n_output, message=False):
-        if span.get_tag("bedrock.request.temperature"):
-            expected_parameters = {"temperature": float(span.get_tag("bedrock.request.temperature"))}
-        if span.get_tag("bedrock.request.max_tokens"):
-            expected_parameters["max_tokens"] = int(span.get_tag("bedrock.request.max_tokens"))
+    def expected_llmobs_span_event_proxy(span, n_output, message=False, metadata=None):
+        expected_parameters = metadata if metadata is not None else mock.ANY
         return _expected_llmobs_non_llm_span_event(
             span,
             span_kind="workflow",
