@@ -6,7 +6,6 @@ from ddtrace import config
 from ddtrace.constants import USER_KEEP
 from ddtrace.contrib.internal.bottle.patch import TracePlugin
 from ddtrace.ext import http
-from ddtrace.internal import compat
 from ddtrace.internal.schema import DEFAULT_SPAN_SERVICE_NAME
 from tests.opentracer.utils import init_tracer
 from tests.tracer.utils_inferred_spans.test_helpers import assert_web_and_inferred_aws_api_gateway_span_data
@@ -56,7 +55,7 @@ class TraceBottleTest(TracerTestCase):
         # make a request
         resp = self.app.get("/hi/dougie" + fqs)
         assert resp.status_int == 200
-        assert compat.to_unicode(resp.body) == "hi dougie"
+        assert resp.body.decode("utf-8", errors="ignore") == "hi dougie"
         # validate it's traced
         spans = self.pop_spans()
         assert len(spans) == 1
@@ -332,7 +331,7 @@ class TraceBottleTest(TracerTestCase):
             resp = self.app.get("/hi/dougie")
 
         assert resp.status_int == 200
-        assert compat.to_unicode(resp.body) == "hi dougie"
+        assert resp.body.decode("utf-8", errors="ignore") == "hi dougie"
         # validate it's traced
         spans = self.pop_spans()
         assert len(spans) == 2
