@@ -1,5 +1,6 @@
 from ddtrace.contrib.internal.django.patch import get_version
 from ddtrace.contrib.internal.django.patch import patch
+from ddtrace.contrib.internal.django.templates import DjangoTemplateWrappingContext
 from tests.contrib.patch import PatchTestCase
 
 
@@ -22,7 +23,7 @@ class TestDjangoPatch(PatchTestCase.Base):
 
         import django.template.base
 
-        self.assert_wrapped(django.template.base.Template.render)
+        assert DjangoTemplateWrappingContext.is_wrapped(django.template.base.Template.render)
         if django.VERSION >= (2, 0, 0):
             self.assert_wrapped(django.urls.path)
             self.assert_wrapped(django.urls.re_path)
@@ -34,7 +35,7 @@ class TestDjangoPatch(PatchTestCase.Base):
 
         self.assert_not_wrapped(django.core.handlers.base.BaseHandler.load_middleware)
         self.assert_not_wrapped(django.core.handlers.base.BaseHandler.get_response)
-        self.assert_not_wrapped(django.template.base.Template.render)
+        assert not DjangoTemplateWrappingContext.is_wrapped(django.template.base.Template.render)
         if django.VERSION >= (2, 0, 0):
             self.assert_not_wrapped(django.urls.path)
             self.assert_not_wrapped(django.urls.re_path)
@@ -46,7 +47,12 @@ class TestDjangoPatch(PatchTestCase.Base):
         self.assert_not_double_wrapped(django.apps.registry.Apps.populate)
         self.assert_not_double_wrapped(django.core.handlers.base.BaseHandler.load_middleware)
         self.assert_not_double_wrapped(django.core.handlers.base.BaseHandler.get_response)
-        self.assert_not_double_wrapped(django.template.base.Template.render)
+
+        assert DjangoTemplateWrappingContext.is_wrapped(django.template.base.Template.render)
+        ctx = DjangoTemplateWrappingContext.extract(django.template.base.Template.render)
+        ctx.unwrap()
+        assert not DjangoTemplateWrappingContext.is_wrapped(django.template.base.Template.render)
+
         if django.VERSION >= (2, 0, 0):
             self.assert_not_double_wrapped(django.urls.path)
             self.assert_not_double_wrapped(django.urls.re_path)
