@@ -26,30 +26,12 @@ from tests.subprocesstest import run_in_subprocess
 PINECONE_VERSION = parse_version(pinecone_.__version__)
 
 
-def _expected_metadata(span, provider):
-    metadata = {}
-    temperature_key = "temperature"
-    if provider == "huggingface_hub":
-        temperature_key = "model_kwargs.temperature"
-        max_tokens_key = "model_kwargs.max_tokens"
-    elif provider == "ai21":
-        max_tokens_key = "maxTokens"
-    else:
-        max_tokens_key = "max_tokens"
-    temperature = span.get_tag(f"langchain.request.{provider}.parameters.{temperature_key}")
-    max_tokens = span.get_tag(f"langchain.request.{provider}.parameters.{max_tokens_key}")
-    if temperature is not None:
-        metadata["temperature"] = float(temperature)
-    if max_tokens is not None:
-        metadata["max_tokens"] = int(max_tokens)
-    return metadata
-
-
 def _expected_langchain_llmobs_llm_span(
-    span, input_role=None, mock_io=False, mock_token_metrics=False, span_links=False
+    span, input_role=None, mock_io=False, mock_token_metrics=False, span_links=False, metadata=None
 ):
     provider = span.get_tag("langchain.request.provider")
-    metadata = _expected_metadata(span, provider)
+
+    metadata = metadata if metadata else mock.ANY
 
     input_messages = [{"content": mock.ANY}]
     output_messages = [{"content": mock.ANY}]
@@ -74,8 +56,8 @@ def _expected_langchain_llmobs_llm_span(
     )
 
 
-def _expected_langchain_llmobs_chain_span(span, input_value=None, output_value=None, span_links=False):
-    metadata = _expected_metadata(span, span.get_tag("langchain.request.provider"))
+def _expected_langchain_llmobs_chain_span(span, input_value=None, output_value=None, span_links=False, metadata=None):
+    metadata = metadata if metadata else mock.ANY
     return _expected_llmobs_non_llm_span_event(
         span,
         "workflow",
@@ -127,9 +109,20 @@ def test_llmobs_openai_chat_model(langchain_openai, llmobs_events, tracer, opena
         span,
         input_role="user",
         mock_token_metrics=True,
+        metadata={"temperature": 0.0, "max_tokens": 256},
     )
 
 
+def test_llmobs_openai_chat_model_no_usage(langchain_openai, llmobs_events, tracer, openai_chat_completion_no_usage):
+    chat_model = langchain_openai.ChatOpenAI(temperature=0, max_tokens=256)
+    chat_model.invoke([HumanMessage(content="When do you use 'who' instead of 'whom'?")])
+
+    assert len(llmobs_events) == 1
+    assert llmobs_events[0]["metrics"].get("input_tokens") is None
+    assert llmobs_events[0]["metrics"].get("output_tokens") is None
+    assert llmobs_events[0]["metrics"].get("total_tokens") is None
+
+
 @mock.patch("langchain_core.language_models.chat_models.BaseChatModel._generate_with_cache")
 def test_llmobs_openai_chat_model_proxy(mock_generate, langchain_openai, llmobs_events, tracer, openai_chat_completion):
     mock_generate.return_value = mock_langchain_chat_generate_response
@@ -141,6 +134,7 @@ def test_llmobs_openai_chat_model_proxy(mock_generate, langchain_openai, llmobs_
     assert llmobs_events[0] == _expected_langchain_llmobs_chain_span(
         span,
         input_value=json.dumps([{"content": "What is the capital of France?", "role": "user"}]),
+        metadata={"temperature": 0.0, "max_tokens": 256},
     )
 
     # span created from request with non-proxy URL should result in an LLM span
@@ -151,13 +145,12 @@ def test_llmobs_openai_chat_model_proxy(mock_generate, langchain_openai, llmobs_
     assert llmobs_events[1]["meta"]["span.kind"] == "llm"
 
 
-def test_llmobs_chain(langchain_core, langchain_openai, llmobs_events, tracer):
+def test_llmobs_chain(langchain_core, langchain_openai, openai_url, llmobs_events, tracer):
     prompt = langchain_core.prompts.ChatPromptTemplate.from_messages(
         [("system", "You are world class technical documentation writer."), ("user", "{input}")]
     )
-    chain = prompt | langchain_openai.OpenAI()
-    with get_request_vcr().use_cassette("lcel_openai_chain_call.yaml"):
-        chain.invoke({"input": "Can you explain what an LLM chain is?"})
+    chain = prompt | langchain_openai.OpenAI(base_url=openai_url)
+    chain.invoke({"input": "Can you explain what an LLM chain is?"})
 
     llmobs_events.sort(key=lambda span: span["start_ns"])
     trace = tracer.pop_traces()[0]
@@ -174,18 +167,17 @@ def test_llmobs_chain(langchain_core, langchain_openai, llmobs_events, tracer):
     )
 
 
-def test_llmobs_chain_nested(langchain_core, langchain_openai, llmobs_events, tracer):
+def test_llmobs_chain_nested(langchain_core, langchain_openai, openai_url, llmobs_events, tracer):
     prompt1 = langchain_core.prompts.ChatPromptTemplate.from_template("what is the city {person} is from?")
     prompt2 = langchain_core.prompts.ChatPromptTemplate.from_template(
         "what country is the city {city} in? respond in {language}"
     )
-    model = langchain_openai.ChatOpenAI()
+    model = langchain_openai.OpenAI(base_url=openai_url)
     chain1 = prompt1 | model | langchain_core.output_parsers.StrOutputParser()
     chain2 = prompt2 | model | langchain_core.output_parsers.StrOutputParser()
     complete_chain = {"city": chain1, "language": itemgetter("language")} | chain2
 
-    with get_request_vcr().use_cassette("lcel_openai_chain_nested.yaml"):
-        complete_chain.invoke({"person": "Spongebob Squarepants", "language": "Spanish"})
+    complete_chain.invoke({"person": "Spongebob Squarepants", "language": "Spanish"})
 
     llmobs_events.sort(key=lambda span: span["start_ns"])
     trace = tracer.pop_traces()[0]
@@ -204,13 +196,11 @@ def test_llmobs_chain_nested(langchain_core, langchain_openai, llmobs_events, tr
     )
     assert llmobs_events[2] == _expected_langchain_llmobs_llm_span(
         trace[2],
-        input_role="user",
         mock_token_metrics=True,
         span_links=True,
     )
     assert llmobs_events[3] == _expected_langchain_llmobs_llm_span(
         trace[3],
-        input_role="user",
         mock_token_metrics=True,
         span_links=True,
     )
@@ -264,7 +254,7 @@ def test_llmobs_chain_batch(langchain_core, langchain_openai, llmobs_events, tra
         )
 
 
-def test_llmobs_chain_schema_io(langchain_core, langchain_openai, llmobs_events, tracer):
+def test_llmobs_chain_schema_io(langchain_core, langchain_openai, openai_url, llmobs_events, tracer):
     prompt = langchain_core.prompts.ChatPromptTemplate.from_messages(
         [
             ("system", "You're an assistant who's good at {ability}. Respond in 20 words or fewer"),
@@ -272,19 +262,18 @@ def test_llmobs_chain_schema_io(langchain_core, langchain_openai, llmobs_events,
             ("human", "{input}"),
         ]
     )
-    chain = prompt | langchain_openai.ChatOpenAI()
+    chain = prompt | langchain_openai.ChatOpenAI(base_url=openai_url)
 
-    with get_request_vcr().use_cassette("lcel_openai_chain_schema_io.yaml"):
-        chain.invoke(
-            {
-                "ability": "world capitals",
-                "history": [
-                    HumanMessage(content="Can you be my science teacher instead?"),
-                    AIMessage(content="Yes"),
-                ],
-                "input": "What's the powerhouse of the cell?",
-            }
-        )
+    chain.invoke(
+        {
+            "ability": "world capitals",
+            "history": [
+                HumanMessage(content="Can you be my science teacher instead?"),
+                AIMessage(content="Yes"),
+            ],
+            "input": "What's the powerhouse of the cell?",
+        }
+    )
 
     llmobs_events.sort(key=lambda span: span["start_ns"])
     trace = tracer.pop_traces()[0]
@@ -300,7 +289,7 @@ def test_llmobs_chain_schema_io(langchain_core, langchain_openai, llmobs_events,
                 }
             ]
         ),
-        output_value=json.dumps(["assistant", "Mitochondria."]),
+        output_value=json.dumps(["assistant", "Mitochondria"]),
         span_links=True,
     )
     assert llmobs_events[1] == _expected_langchain_llmobs_llm_span(
@@ -322,6 +311,7 @@ def test_llmobs_anthropic_chat_model(langchain_anthropic, llmobs_events, tracer)
         span,
         input_role="user",
         mock_token_metrics=True,
+        metadata={"temperature": 0, "max_tokens": 15},
     )
 
 
@@ -555,10 +545,9 @@ def test_llmobs_streamed_llm(langchain_openai, llmobs_events, tracer, streamed_r
     )
 
 
-def test_llmobs_non_ascii_completion(langchain_openai, llmobs_events, tracer):
-    llm = langchain_openai.OpenAI()
-    with get_request_vcr().use_cassette("openai_completion_non_ascii.yaml"):
-        llm.invoke("안녕,\n 지금 몇 시야?")
+def test_llmobs_non_ascii_completion(langchain_openai, openai_url, llmobs_events):
+    llm = langchain_openai.OpenAI(base_url=openai_url)
+    llm.invoke("안녕,\n 지금 몇 시야?")
 
     assert len(llmobs_events) == 1
     actual_llmobs_span_event = llmobs_events[0]
@@ -646,7 +635,7 @@ class TestTraceStructureWithLLMIntegrations(SubprocessTestCase):
         llm = BedrockLLM(
             model_id="amazon.titan-tg1-large",
             region_name="us-east-1",
-            model_kwargs={"temperature": 0, "topP": 0.9, "stopSequences": [], "maxTokenCount": 50},
+            model_kwargs={"temperature": 0.0, "topP": 0.9, "stopSequences": [], "maxTokenCount": 50},
         )
 
         with get_request_vcr().use_cassette("bedrock_amazon_invoke.yaml"):
@@ -732,9 +721,8 @@ class TestTraceStructureWithLLMIntegrations(SubprocessTestCase):
 
         patch(langchain=True, openai=True)
         LLMObs.enable(ml_app="<ml-app-name>", integrations_enabled=False)
-        llm = OpenAI()
-        with get_request_vcr().use_cassette("openai_completion_non_ascii.yaml"):
-            llm.invoke("안녕,\n 지금 몇 시야?")
+        llm = OpenAI(base_url="http://localhost:9126/vcr/openai")
+        llm.invoke("안녕,\n 지금 몇 시야?")
         langchain_span = self.mock_llmobs_span_writer.enqueue.call_args_list[1][0][0]
         assert langchain_span["meta"]["input"]["value"] == '[{"content": "안녕,\\n 지금 몇 시야?"}]'
 
