@@ -57,8 +57,8 @@ def test_connection_no_port_or_user_does_not_raise():
     try:
         mariadb.connect(**conf)
     except mariadb.OperationalError as exc:
-        # this error is expected because mariadb defaults user to root when not given
-        if "Access denied for user 'root'" not in str(exc):
+        # this error is expected because mariadb defaults user to root/bits when not given
+        if "Access denied for user '" not in str(exc):
             raise exc
 
 
