@@ -2,10 +2,9 @@ import warnings
 
 import pytest
 
-from ddtrace._logger import LogInjectionState
-from ddtrace.settings import HttpConfig
-from ddtrace.settings import IntegrationConfig
 from ddtrace.settings._config import Config
+from ddtrace.settings.http import HttpConfig
+from ddtrace.settings.integration import IntegrationConfig
 from tests.utils import BaseTestCase
 from tests.utils import override_env
 
@@ -14,20 +13,24 @@ class TestConfig(BaseTestCase):
     def test_logs_injection(self):
         with self.override_env(dict(DD_LOGS_INJECTION="True")):
             config = Config()
-            self.assertEqual(config._logs_injection, LogInjectionState.ENABLED)
+            self.assertEqual(config._logs_injection, True)
 
         with self.override_env(dict(DD_LOGS_INJECTION="FALSE")):
             config = Config()
-            self.assertEqual(config._logs_injection, LogInjectionState.DISABLED)
+            self.assertEqual(config._logs_injection, False)
+
+        with self.override_env(dict(DD_LOGS_INJECTION="structured")):
+            config = Config()
+            self.assertEqual(config._logs_injection, True)
 
         with self.override_env(dict(), replace_os_env=True):
             config = Config()
-            self.assertEqual(config._logs_injection, LogInjectionState.STRUCTURED)
+            self.assertEqual(config._logs_injection, True)
 
-        with self.override_env(dict(DD_LOGS_INJECTION="nonesense")):
+        with self.override_env(dict(DD_LOGS_INJECTION="nonsense")):
             # If the value is not recognized, it should default to DISABLED
             config = Config()
-            self.assertEqual(config._logs_injection, LogInjectionState.DISABLED)
+            self.assertEqual(config._logs_injection, False)
 
     def test_service(self):
         # If none is provided the default should be ``None``
@@ -240,3 +243,68 @@ def test_x_datadog_tags(env, expected):
     with override_env(env):
         _ = Config()
         assert expected == (_._x_datadog_tags_max_length, _._x_datadog_tags_enabled)
+
+
+@pytest.mark.subprocess()
+def test_config_exception_deprecation():
+    import warnings
+
+    with warnings.catch_warnings(record=True) as warns:
+        warnings.simplefilter("default")
+
+        from ddtrace.settings import ConfigException  # noqa: F401
+
+        assert len(warns) == 1
+        warn = warns[0]
+
+        assert issubclass(warn.category, DeprecationWarning)
+        assert "ddtrace.settings.ConfigException is deprecated" in str(warn.message)
+        assert "4.0.0" in str(warn.message)  # TODO: update the version
+
+
+@pytest.mark.subprocess()
+def test_http_config_deprecation():
+    import warnings
+
+    with warnings.catch_warnings(record=True) as warns:
+        warnings.simplefilter("default")
+
+        from ddtrace.settings import HttpConfig  # noqa: F401
+
+        assert len(warns) == 1
+        warn = warns[0]
+        assert issubclass(warn.category, DeprecationWarning)
+        assert "ddtrace.settings.HttpConfig is deprecated" in str(warn.message)
+        assert "4.0.0" in str(warn.message)  # TODO: update the version
+
+
+@pytest.mark.subprocess()
+def test_hooks_deprecation():
+    import warnings
+
+    with warnings.catch_warnings(record=True) as warns:
+        warnings.simplefilter("default")
+
+        from ddtrace.settings import Hooks  # noqa: F401
+
+        assert len(warns) == 1
+        warn = warns[0]
+        assert issubclass(warn.category, DeprecationWarning)
+        assert "ddtrace.settings.Hooks is deprecated" in str(warn.message)
+        assert "4.0.0" in str(warn.message)  # TODO: update the version
+
+
+@pytest.mark.subprocess()
+def test_integration_config_deprecation():
+    import warnings
+
+    with warnings.catch_warnings(record=True) as warns:
+        warnings.simplefilter("default")
+
+        from ddtrace.settings import IntegrationConfig  # noqa: F401
+
+        assert len(warns) == 1
+        warn = warns[0]
+        assert issubclass(warn.category, DeprecationWarning)
+        assert "ddtrace.settings.IntegrationConfig is deprecated" in str(warn.message)
+        assert "4.0.0" in str(warn.message)  # TODO: update the version
