@@ -632,7 +632,7 @@ ALL_IP_HEADERS = (
     ("x-real-ip", "2.2.2.2"),
     ("true-client-ip", "3.3.3.3"),
     ("x-client-ip", "4.4.4.4"),
-    ("x-forwarded", "5.5.5.5"),
+    ("forwarded", 'by=1.2.3.4;for="5.5.5.5:2000";host=test.zouzou.ncom'),
     ("forwarded-for", "6.6.6.6"),
     ("x-cluster-client-ip", "7.7.7.7"),
     ("fastly-client-ip", "8.8.8.8"),
@@ -644,8 +644,9 @@ ALL_IP_HEADERS = (
 ALL_TESTS = [
     ["", dict(ALL_IP_HEADERS[-1 : -i - 2 : -1]), ALL_IP_HEADERS[-1 - i][1]] for i in range(len(ALL_IP_HEADERS))
 ]
-# x-forwarded is now ignored so we fall back to forwarded-for
-ALL_TESTS[5][2] = "6.6.6.6"
+
+# expected value for forwarded is extracted from for
+ALL_TESTS[5][2] = "5.5.5.5"
 
 
 @pytest.mark.parametrize(
@@ -689,6 +690,49 @@ ALL_TESTS[5][2] = "6.6.6.6"
             {"x-forwarded-for": "4.4.4.4", "x-real-ip": "8.8.4.4"},
             "8.8.4.4",
         ),
+        (
+            "",
+            {"forwarded": 'by=1.2.3.4;for="[9f7b:5e67:5472:4464:90b0:6b0a:9aa6:f9dc]:2000";host=test.zouzou.ncom'},
+            "9f7b:5e67:5472:4464:90b0:6b0a:9aa6:f9dc",
+        ),
+        (
+            "",
+            {"forwarded": 'by=1.2.3.4;for="[9f7b:5e67:5472:4464:90b0:6b0a:9aa6:f9dc]";host=test.zouzou.ncom'},
+            "9f7b:5e67:5472:4464:90b0:6b0a:9aa6:f9dc",
+        ),
+        (
+            "",
+            {"forwarded": 'by=1.2.3.4;for="3.3.3.3:1321";host=test.zouzou.ncom'},
+            "3.3.3.3",
+        ),
+        (
+            "",
+            {"forwarded": 'by=1.2.3.4;For="3.3.3.3";host=test.zouzou.ncom'},
+            "3.3.3.3",
+        ),
+        (
+            "",
+            {"forwarded": "by=1.2.3.4;FOR=3.3.3.3;host=test.zouzou.ncom"},
+            "3.3.3.3",
+        ),
+        (
+            "",
+            {"forwarded": "by=1.2.3.4;FOR=127.0.0.1;host=test.zouzou.ncom, For=4.5.6.7, For=5.6.7.8"},
+            "4.5.6.7",
+        ),
+        (
+            "",
+            {"x-forwarded-for": "127.0.0.1, 3.4.5.6"},
+            "3.4.5.6",
+        ),
+        (
+            "",
+            {
+                "forwarded": "by=1.2.3.4;FOR=127.0.0.3;host=test.zouzou.ncom,"
+                " by=1.2.3.4;FOR=127.0.0.4, by=1.2.3.4;FOR=127.0.0.5"
+            },
+            "127.0.0.3",
+        ),
     ]
     + ALL_TESTS,
 )
