@@ -34,7 +34,7 @@ from ddtrace.internal.compat import PYTHON_VERSION_INFO
 from ddtrace.internal.rate_limiter import RateLimiter
 from ddtrace.internal.serverless import has_aws_lambda_agent_extension
 from ddtrace.internal.serverless import in_aws_lambda
-from ddtrace.internal.writer import AgentWriter
+from ddtrace.internal.writer import AgentWriterInterface
 from ddtrace.internal.writer import LogWriter
 from ddtrace.settings._config import Config
 from ddtrace.trace import Context
@@ -684,18 +684,17 @@ class TracerTestCases(TracerTestCase):
 def test_tracer_url_default():
     import ddtrace
 
-    assert ddtrace.trace.tracer._span_aggregator.writer.agent_url == "http://localhost:8126"
+    assert ddtrace.trace.tracer._span_aggregator.writer.intake_url == "http://localhost:8126"
 
 
 @pytest.mark.subprocess()
 def test_tracer_shutdown_no_timeout():
     import mock
 
-    from ddtrace.internal.writer import AgentWriter
     from ddtrace.trace import tracer as t
 
-    with mock.patch.object(AgentWriter, "stop") as mock_stop:
-        with mock.patch.object(AgentWriter, "join") as mock_join:
+    with mock.patch.object(t._span_aggregator.writer, "stop") as mock_stop:
+        with mock.patch.object(t._span_aggregator.writer, "join") as mock_join:
             t.shutdown()
 
     mock_stop.assert_called()
@@ -706,10 +705,9 @@ def test_tracer_shutdown_no_timeout():
 def test_tracer_shutdown_timeout():
     import mock
 
-    from ddtrace.internal.writer import AgentWriter
     from ddtrace.trace import tracer as t
 
-    with mock.patch.object(AgentWriter, "stop") as mock_stop:
+    with mock.patch.object(t._span_aggregator.writer, "stop") as mock_stop:
         with t.trace("something"):
             pass
 
@@ -723,12 +721,11 @@ def test_tracer_shutdown_timeout():
 def test_tracer_shutdown():
     import mock
 
-    from ddtrace.internal.writer import AgentWriter
     from ddtrace.trace import tracer as t
 
     t.shutdown()
 
-    with mock.patch.object(AgentWriter, "write") as mock_write:
+    with mock.patch.object(t._span_aggregator.writer, "write") as mock_write:
         with t.trace("something"):
             pass
 
@@ -941,7 +938,7 @@ class EnvTracerTestCase(TracerTestCase):
 
     @run_in_subprocess(env_overrides=dict(AWS_LAMBDA_FUNCTION_NAME="my-func", DD_AGENT_HOST="localhost"))
     def test_detect_agent_config(self):
-        assert isinstance(global_tracer._span_aggregator.writer, AgentWriter)
+        assert isinstance(global_tracer._span_aggregator.writer, AgentWriterInterface)
 
     @run_in_subprocess(env_overrides=dict(DD_TAGS="key1:value1,key2:value2"))
     def test_dd_tags(self):
@@ -1043,10 +1040,16 @@ def test_start_span_hooks():
     def store_span(span):
         result["span"] = span
 
-    span = t.start_span("hello")
+    try:
+        span = t.start_span("hello")
 
-    assert span == result["span"]
-    span.finish()
+        assert span == result["span"]
+        span.finish()
+    finally:
+        # Cleanup after the test is done
+        # DEV: Since we use the core API for these hooks,
+        #      they are not isolated to a single tracer instance
+        t.deregister_on_start_span(store_span)
 
 
 def test_deregister_start_span_hooks():
@@ -1088,8 +1091,6 @@ def test_enable():
 )
 def test_unfinished_span_warning_log():
     """Test that a warning log is emitted when the tracer is shut down with unfinished spans."""
-    import ddtrace.auto  # noqa
-
     from ddtrace.constants import MANUAL_KEEP_KEY
     from ddtrace.trace import tracer
 
@@ -1974,14 +1975,14 @@ def test_detect_agent_config_with_lambda_extension():
 
     with mock.patch("os.path.exists", side_effect=mock_os_path_exists):
         import ddtrace
-        from ddtrace.internal.writer import AgentWriter
+        from ddtrace.internal.writer import AgentWriterInterface
         from ddtrace.trace import tracer
 
         assert ddtrace.internal.serverless.in_aws_lambda()
 
         assert ddtrace.internal.serverless.has_aws_lambda_agent_extension()
 
-        assert isinstance(tracer._span_aggregator.writer, AgentWriter)
+        assert isinstance(tracer._span_aggregator.writer, AgentWriterInterface)
         assert tracer._span_aggregator.writer._sync_mode
 
 
